@@ -30,8 +30,8 @@ class TestReservationV2API(unittest.TestCase):
         cred = credentials.Certificate(cred)
         firebase_admin.initialize_app(cred, name='alvie')
 
-        resv = rms.ReservationSync('11249')
-        resv_list = [8787]
+        resv = rms.ReservationSync('11281')
+        resv_list = [169410, 169411]
         for _resv_id in resv_list:
             start_time = datetime.datetime.now()
             print(f'processing reservation : {_resv_id}')
