@@ -29,6 +29,8 @@ def _get_status(status):
         return Status.MAINTENANCE
     elif status == 'Confirmed':
         return Status.CONFIRMED
+    elif status == 'Pencil':
+        return Status.PENCIL
     else:
         logging.error(f'Missing Status : {status}')
         return Status.UNCONFIRMED
@@ -260,7 +262,7 @@ class ReservationSync:
             logging.error(e)
 
         hotelId = self.mongo.get_collection(self.mongo.PROPERTY_COLLECTION).find_one({'primaryDetails.propertyId': str(record.get('propertyId'))}, {'_id': 1})
-        hotelId = hotelId if hotelId else '0'
+        hotelId = hotelId.get('_id') if hotelId else '0'
         guest = GuestsModelV2(
             _id=str(record.get('id')),
             idObj=_create_guest_id_obj(record),
@@ -762,7 +764,7 @@ class ReservationSync:
                      'hotelId': 1}
                 )
                 response_json['clientId'] = property_info.get('hotelId') if property_info else 0
-                response_json['propertyId'] = property_info.get('primaryDetails.propertyId') if property_info else 0
+                response_json['propertyId'] = property_info.get('primaryDetails').get('propertyId') if property_info else 0
                 response_json['propertyName'] = property_info.get('name') if property_info else 'Unknown'
                 return response_json
             except Exception as err:
